==> php54-owncloud-7.0.4.tgz: share/owncloud/apps/calendar/l10n/sl.php <==
<?php $TRANSLATIONS = array(
"Not all calendars are completely cached" => "Vsi koledarji niso popolnoma predpomnjeni",
"Everything seems to be completely cached" => "Videti je, da so vsi predmeti predpomnjeni",
"No calendars found." => "Ni najdenih koledarjev.",
"No events found." => "Ni najdenih dogodkov.",
"Wrong calendar" => "Napačen koledar",
"You do not have the permissions to edit this event." => "Ni ustreznih dovoljenj za urejanje tega dogodka.",
"The file contained either no events or all events are already saved in your calendar." => "Datoteka ni vsebovala dogodkov, ali pa so vsi že shranjeni v koledarju.",
"events have been saved in the new calendar" => "v novi koledar so bili shranjeni dogodki",
"Import failed" => "Uvoz je spodletel",
"events have been saved in your calendar" => "v koledar so bili shranjeni novi dogodki",
"New Timezone:" => "Nov časovni pas:",
"Timezone changed" => "Časovni pas je spremenjen",
"Invalid request" => "Neveljavna zahteva",
"Calendar" => "Koledar",
"Deletion failed" => "Brisanje je spodletelo.",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd, d. MMMM [ yyyy]{ - [ddd, d.] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd. d. MMMM[ yyyy] HH:mm{ - [ ddd. d. MMMM yyyy] HH:mm}",
"group" => "skupina",
"can edit" => "lahko ureja",
"can share" => "lahko omogoči souporabo",
"ddd" => "ddd",
"ddd M/d" => "ddd, d. M.",
"dddd M/d" => "dddd, d. M.",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "d. MMM[ yyyy]{ '–' d.[ MMM] yyyy}",
"dddd, MMM d, yyyy" => "dddd, d. MMM yyyy",
"Sunday" => "nedelja",
"Monday" => "ponedeljek",
"Tuesday" => "torek",
"Wednesday" => "sreda",
"Thursday" => "četrtek",
"Friday" => "petek",
"Saturday" => "sobota",
"Sun." => "ned",
"Mon." => "pon",
"Tue." => "tor",
"Wed." => "sre",
"Thu." => "čet",
"Fri." => "pet",
"Sat." => "sob",
"January" => "januar",
"February" => "februar",
"March" => "marec",
"April" => "april",
"May" => "maj",
"June" => "junij",
"July" => "julij",
"August" => "avgust",
"September" => "september",
"October" => "oktober",
"November" => "november",
"December" => "december",
"Jan." => "jan",
"Feb." => "feb",
"Mar." => "mar",
"Apr." => "apr",
"May." => "maj",
"Jun." => "jun",
"Jul." => "jul",
"Aug." => "avg",
"Sep." => "sep",
"Oct." => "okt",
"Nov." => "nov",
"Dec." => "dec",
"All day" => "Cel dan",
"New Calendar" => "Nov koledar",
"Missing or invalid fields" => "Manjkajoča ali neveljavna polja",
"Title" => "Naslov",
"From Date" => "Od datuma",
"From Time" => "Od časa",
"To Date" => "Do datuma",
"To Time" => "Do časa",
"The event ends before it starts" => "Dogodek se konča preden se začne",
"There was a database fail" => "Napaka v podatkovni zbirki",
"Interval is not valid. It must be a positive integer!" => "Določilo časovnega razmika ni veljavno. Vrednost mora biti pozitivno celo število..",
"Birthday" => "Rojstni dan",
"Business" => "Poslovno",
"Call" => "Pokliči",
"Clients" => "Stranke",
"Deliverer" => "Dobavitelj",
"Holidays" => "Dopust",
"Ideas" => "Ideje",
"Journey" => "Potovanje",
"Jubilee" => "Obletnica",
"Meeting" => "Srečanje",
"Other" => "Drugo",
"Personal" => "Osebno",
"Projects" => "Projekti",
"Questions" => "Vprašanja",
"Work" => "Delo",
"by" => "od",
"unnamed" => "neimenovano",
"You do not have the permissions to update this calendar." => "Ni ustreznih dovoljenj za posodobitev tega koledarja.",
"You do not have the permissions to delete this calendar." => "Ni ustreznih dovoljenj za izbris tega koledarja.",
"You do not have the permissions to add to this calendar." => "Ni ustreznih dovoljenj za dodajanje tega koledarja.",
"You do not have the permissions to add events to this calendar." => "Ni ustreznih dovoljenj za dodajanje dogodkov v ta koledar.",
"You cannot add non-public events to a shared calendar." => "V koledar v souporabi ni mogoče dodati zasebnih dogodkov.",
"You do not have the permissions to delete this event." => "Ni ustreznih dovoljenj za izbris tega dogodka.",
"Busy" => "Zasedeno",
"Show full event" => "Pokaži poln dogodek",
"Show only busy" => "Pokaži le zasedeno",
"Hide event" => "Skrij dogodek",
"Does not repeat" => "Se ne ponavlja",
"Daily" => "Dnevno",
"Weekly" => "Tedensko",
"Every Weekday" => "Vsak dan v tednu",
"Bi-Weekly" => "Dvakrat mesečno",
"Monthly" => "Mesečno",
"Yearly" => "Letno",
"never" => "nikoli",
"by occurrences" => "po pojavljanju",
"by date" => "po datumu",
"by monthday" => "po dnevu v mesecu",
"by weekday" => "po dnevu v tednu",
"events week of month" => "dogodki tedna v mesecu",
"first" => "prvi",
"second" => "drugi",
"third" => "tretji",
"fourth" => "četrti",
"fifth" => "peti",
"last" => "zadnji",
"by events date" => "po datumu dogodka",
"by yearday(s)" => "po številu let",
"by weeknumber(s)" => "po tednu v letu",
"by day and month" => "po dnevu in mesecu",
"Contact birthdays" => "Rojstni dan stika",
"Date" => "Datum",
"Cal." => "Kol.",
"Day" => "Dan",
"Week" => "Teden",
"Month" => "Mesec",
"Today" => "Danes",
"CalDav Link" => "Povezava CalDav",
"Timezone" => "Časovni pas",
"Update timezone automatically" => "Samodejno posodobi časovne podatke",
"Time format" => "Oblika zapisa časa",
"24h" => "24 ur",
"12h" => "12 ur",
"Start week on" => "Začni teden na",
"Cache" => "Predpomnilnik",
"Clear cache for repeating events" => "Počisti predpomnilnik ponavljajočih se dogodkov",
"Primary CalDAV address" => "Osnovni naslov CalDAV",
"iOS/OS X CalDAV address" => "Naslov CalDAV iOS/OS",
"Share Calendar" => "Daj koledar v souporabo",
"Download" => "Prejmi",
"Edit" => "Uredi",
"Delete" => "Izbriši",
"New calendar" => "Nov koledar",
"Edit calendar" => "Uredi koledar",
"Edit event" => "Uredi dogodek",
"Save event" => "Shrani dogodek",
"Delete event" => "Izbriši dogodek",
"Eventinfo" => "Podrobnosti dogodka",
"Repeating" => "Ponavljanje",
"Alarm" => "Alarm",
"Attendees" => "Udeleženci",
"Share" => "Souporaba",
"Title of the Event" => "Naslov dogodka",
"from" => "od",
"to" => "do",
"All Day Event" => "Celodnevni dogodek",
"Advanced options" => "Napredne možnosti",
"Location" => "Mesto",
"Categories (separate by comma)" => "Kategorije (ločene z vejico)",
"Edit categories" => "Uredi kategorije",
"Description" => "Opis",
"Export event" => "Izvozi dogodek",
"Repeat" => "Ponovi",
"Advanced" => "Napredno",
"Select weekdays" => "Izbor delovnih dni tedna",
"Select days" => "Izberite dneve",
"and the events day of year." => "in dnevu dogodka v letu.",
"and the events day of month." => "in dnevu dogodka v mesecu.",
"Select months" => "Izberite mesece",
"Select weeks" => "Izberite tedne",
"and the events week of year." => "in tednu dogodka v letu.",
"Interval" => "Časovni razmik",
"End" => "Konec",
"occurrences" => "pojavitve",
"Visibility to people shared with" => "Vidno posameznikom v souporabi",
"create a new calendar" => "Ustvari nov koledar",
"Import a calendar file" => "Uvozi datoteko koledarja",
"Please choose a calendar" => "Izberite koledar",
"Name of new calendar" => "Ime novega koledarja",
"Take an available name!" => "Izberite ime, ki še ni v uporabi!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Koledar s tem imenom že obstaja. Z nadaljevanjem bosta vsebini koledarjev združeni.",
"Remove all events from the selected calendar" => "Odstrani vse dogodke iz izbranega koledarja",
"Import" => "Uvozi",
"Close Dialog" => "Zapri pogovorno okno",
"Create a new event" => "Ustvari nov dogodek",
"Create event" => "Ustvari dogodek",
"Share with user or group" => "Omogoči souporabo s skupino ali z uporabnikom",
"Unshare" => "Prekliči souporabo",
"Not shared with anyone" => "Ni v souporabi",
"Send Email" => "Pošlji elektronsko sporočilo",
"Shared via calendar" => "V souporabi preko koledarja",
"Not shared with anyone via calendar" => "Ni v souporabi preko koledarja",
"View an event" => "Poglej dogodek",
"Category" => "Kategorija",
"No categories selected" => "Ni izbrane kategorije",
"%s of %s" => "%s od %s",
"Access Class" => "Razred dostopa",
"From" => "Od",
"at" => "pri",
"To" => "Do"
);

==> php54-owncloud-8.0.4.tgz: share/owncloud/apps/calendar/l10n/sl.php <==
<?php
$TRANSLATIONS = array(
"Not all calendars are completely cached" => "Vsi koledarji niso popolnoma predpomnjeni",
"Everything seems to be completely cached" => "Videti je, da so vsi predmeti predpomnjeni",
"No calendars found." => "Ni najdenih koledarjev.",
"No events found." => "Ni najdenih dogodkov.",
"Wrong calendar" => "Napačen koledar",
"You do not have the permissions to edit this event." => "Ni ustreznih dovoljenj za urejanje tega dogodka.",
"The file contained either no events or all events are already saved in your calendar." => "Datoteka ni vsebovala dogodkov, ali pa so vsi že shranjeni v koledarju.",
"events have been saved in the new calendar" => "v novi koledar so bili shranjeni dogodki",
"Import failed" => "Uvoz je spodletel",
"events have been saved in your calendar" => "v koledar so bili shranjeni novi dogodki",
"New Timezone:" => "Nov časovni pas:",
"Timezone changed" => "Časovni pas je spremenjen",
"Invalid request" => "Neveljavna zahteva",
"Calendar" => "Koledar",
"Error sending mail" => "Napaka pošiljanja sporočila",
"Deletion failed" => "Brisanje je spodletelo.",
"ddd d MMMM[ yyyy]{ - [ddd d] MMMM yyyy}" => "ddd, d. MMMM [ yyyy]{ - [ddd, d.] MMMM yyyy}",
"ddd d MMMM[ yyyy] HH:mm{ - [ ddd d MMMM yyyy] HH:mm}" => "ddd. d. MMMM[ yyyy] HH:mm{ - [ ddd. d. MMMM yyyy] HH:mm}",
"Do you really want to delete this calendar?" => "Ali res želite izbrisati koledar?",
"group" => "skupina",
"can edit" => "lahko ureja",
"can share" => "lahko omogoči souporabo",
"ddd" => "ddd",
"ddd M/d" => "ddd, d. M.",
"dddd M/d" => "dddd, d. M.",
"MMMM yyyy" => "MMMM yyyy",
"MMM d[ yyyy]{ '–'[ MMM] d yyyy}" => "d. MMM[ yyyy]{ '–' d.[ MMM] yyyy}",
"dddd, MMM d, yyyy" => "dddd, d. MMM yyyy",
"Sunday" => "nedelja",
"Monday" => "ponedeljek",
"Tuesday" => "torek",
"Wednesday" => "sreda",
"Thursday" => "četrtek",
"Friday" => "petek",
"Saturday" => "sobota",
"Sun." => "ned",
"Mon." => "pon",
"Tue." => "tor",
"Wed." => "sre",
"Thu." => "čet",
"Fri." => "pet",
"Sat." => "sob",
"January" => "januar",
"February" => "februar",
"March" => "marec",
"April" => "april",
"May" => "maj",
"June" => "junij",
"July" => "julij",
"August" => "avgust",
"September" => "september",
"October" => "oktober",
"November" => "november",
"December" => "december",
"Jan." => "jan",
"Feb." => "feb",
"Mar." => "mar",
"Apr." => "apr",
"May." => "maj",
"Jun." => "jun",
"Jul." => "jul",
"Aug." => "avg",
"Sep." => "sep",
"Oct." => "okt",
"Nov." => "nov",
"Dec." => "dec",
"All day" => "Cel dan",
"New Calendar" => "Nov koledar",
"Missing or invalid fields" => "Manjkajoča ali neveljavna polja",
"Title" => "Naslov",
"From Date" => "Od datuma",
"From Time" => "Od časa",
"To Date" => "Do datuma",
"To Time" => "Do časa",
"The event ends before it starts" => "Dogodek se konča preden se začne",
"There was a database fail" => "Napaka v podatkovni zbirki",
"Interval is not valid. It must be a positive integer!" => "Določilo časovnega razmika ni veljavno. Vrednost mora biti pozitivno celo število..",
"Birthday" => "Rojstni dan",
"Business" => "Poslovno",
"Call" => "Pokliči",
"Clients" => "Stranke",
"Deliverer" => "Dobavitelj",
"Holidays" => "Dopust",
"Ideas" => "Ideje",
"Journey" => "Potovanje",
"Jubilee" => "Obletnica",
"Meeting" => "Srečanje",
"Other" => "Drugo",
"Personal" => "Osebno",
"Projects" => "Projekti",
"Questions" => "Vprašanja",
"Work" => "Delo",
"by" => "od",
"unnamed" => "neimenovano",
"You do not have the permissions to update this calendar." => "Ni ustreznih dovoljenj za posodobitev tega koledarja.",
"You do not have the permissions to delete this calendar." => "Ni ustreznih dovoljenj za izbris tega koledarja.",
"You do not have the permissions to add to this calendar." => "Ni ustreznih dovoljenj za dodajanje tega koledarja.",
"You do not have the permissions to add events to this calendar." => "Ni ustreznih dovoljenj za dodajanje dogodkov v ta koledar.",
"You cannot add non-public events to a shared calendar." => "V koledar v souporabi ni mogoče dodati zasebnih dogodkov.",
"You do not have the permissions to delete this event." => "Ni ustreznih dovoljenj za izbris tega dogodka.",
"Busy" => "Zasedeno",
"Show full event" => "Pokaži poln dogodek",
"Show only busy" => "Pokaži le zasedeno",
"Hide event" => "Skrij dogodek",
"Does not repeat" => "Se ne ponavlja",
"Daily" => "Dnevno",
"Weekly" => "Tedensko",
"Every Weekday" => "Vsak dan v tednu",
"Bi-Weekly" => "Dvakrat mesečno",
"Monthly" => "Mesečno",
"Yearly" => "Letno",
"never" => "nikoli",
"by occurrences" => "po pojavljanju",
"by date" => "po datumu",
"by monthday" => "po dnevu v mesecu",
"by weekday" => "po dnevu v tednu",
"events week of month" => "dogodki tedna v mesecu",
"first" => "prvi",
"second" => "drugi",
"third" => "tretji",
"fourth" => "četrti",
"fifth" => "peti",
"last" => "zadnji",
"by events date" => "po datumu dogodka",
"by yearday(s)" => "po številu let",
"by weeknumber(s)" => "po tednu v letu",
"by day and month" => "po dnevu in mesecu",
"Contact birthdays" => "Rojstni dan stika",
"Date" => "Datum",
"Day" => "Dan",
"Week" => "Teden",
"Month" => "Mesec",
"Today" => "Danes",
"CalDav Link" => "Povezava CalDav",
"Timezone" => "Časovni pas",
"Update timezone automatically" => "Samodejno posodobi časovne podatke",
"Time format" => "Oblika zapisa časa",
"24h" => "24 ur",
"12h" => "12 ur",
"Start week on" => "Začni teden na",
"Cache" => "Predpomnilnik",
"Clear cache for repeating events" => "Počisti predpomnilnik ponavljajočih se dogodkov",
"Primary CalDAV address" => "Osnovni naslov CalDAV",
"iOS/OS X CalDAV address" => "Naslov CalDAV iOS/OS",
"Share Calendar" => "Daj koledar v souporabo",
"Download" => "Prejmi",
"Edit" => "Uredi",
"Delete" => "Izbriši",
"New calendar" => "Nov koledar",
"Edit calendar" => "Uredi koledar",
"Edit event" => "Uredi dogodek",
"Save event" => "Shrani dogodek",
"Delete event" => "Izbriši dogodek",
"Eventinfo" => "Podrobnosti dogodka",
"Repeating" => "Ponavljanje",
"Alarm" => "Alarm",
"Attendees" => "Udeleženci",
"Share" => "Souporaba",
"Title of the Event" => "Naslov dogodka",
"from" => "od",
"to" => "do",
"All Day Event" => "Celodnevni dogodek",
"Advanced options" => "Napredne možnosti",
"Location" => "Mesto",
"Categories (separate by comma)" => "Kategorije (ločene z vejico)",
"Edit categories" => "Uredi kategorije",
"Description" => "Opis",
"Export event" => "Izvozi dogodek",
"Repeat" => "Ponovi",
"Advanced" => "Napredno",
"Select weekdays" => "Izbor delovnih dni tedna",
"Select days" => "Izberite dneve",
"and the events day of year." => "in dnevu dogodka v letu.",
"and the events day of month." => "in dnevu dogodka v mesecu.",
"Select months" => "Izberite mesece",
"Select weeks" => "Izberite tedne",
"and the events week of year." => "in tednu dogodka v letu.",
"Interval" => "Časovni razmik",
"End" => "Konec",
"occurrences" => "pojavitve",
"Visibility to people shared with" => "Vidno posameznikom v souporabi",
"create a new calendar" => "Ustvari nov koledar",
"Import a calendar file" => "Uvozi datoteko koledarja",
"Please choose a calendar" => "Izberite koledar",
"Name of new calendar" => "Ime novega koledarja",
"Take an available name!" => "Izberite ime, ki še ni v uporabi!",
"A Calendar with this name already exists. If you continue anyhow, these calendars will be merged." => "Koledar s tem imenom že obstaja. Z nadaljevanjem bosta vsebini koledarjev združeni.",
"Remove all events from the selected calendar" => "Odstrani vse dogodke iz izbranega koledarja",
"Import" => "Uvozi",
"Close Dialog" => "Zapri pogovorno okno",
"Create a new event" => "Ustvari nov dogodek",
"Create event" => "Ustvari dogodek",
"Share with user or group" => "Omogoči souporabo s skupino ali z uporabnikom",
"Unshare" => "Prekliči souporabo",
"Not shared with anyone" => "Ni v souporabi",
"Send Email" => "Pošlji elektronsko sporočilo",
"Shared via calendar" => "V souporabi preko koledarja",
"Not shared with anyone via calendar" => "Ni v souporabi preko koledarja",
"View an event" => "Poglej dogodek",
"Category" => "Kategorija",
"No categories selected" => "Ni izbrane kategorije",
"%s of %s" => "%s od %s",
"Access Class" => "Razred dostopa",
"From" => "Od",
"at" => "pri",
"To" => "Do"
);
$PLURAL_FORMS = "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);";
